Index: third_party/WebKit/Source/modules/bluetooth/BluetoothUUID.cpp |
diff --git a/third_party/WebKit/Source/modules/bluetooth/BluetoothUUID.cpp b/third_party/WebKit/Source/modules/bluetooth/BluetoothUUID.cpp |
index 77b1ac583398ad021cc2339548c713e38de9691b..7a8a3ac17b38ace94eab356f2f40448ba27b30bf 100644 |
--- a/third_party/WebKit/Source/modules/bluetooth/BluetoothUUID.cpp |
+++ b/third_party/WebKit/Source/modules/bluetooth/BluetoothUUID.cpp |
@@ -327,8 +327,8 @@ String getUUIDForGATTAttribute(GATTAttribute attribute, StringOrUnsignedLong nam |
" e.g. 'gatt.characteristic_presentation_format'."); |
break; |
} |
- // Otherwise, throw a SyntaxError. |
- exceptionState.throwDOMException(SyntaxError, errorMessage.toString()); |
+ // Otherwise, throw a TypeError. |
+ exceptionState.throwDOMException(V8TypeError, errorMessage.toString()); |
return String(); |
} |